' === Pi_PS_Test2.bas =====================================================================

'Program uses a voltage divider to determine the real-time battery voltage of the Pi UPS.
'It also monitors the real-time digital level (on/off) of the main power supply to the UPS.

' === Directives ===
  #com 3                          'specify serial port
  #picaxe 08M2                    'specify processor
  #terminal 4800                  'open the terminal window
  #no_data                        'save time downloading

' === Constants ======
  symbol    batt = C.4            'voltage divider connected to pin C.4
  
' === Variables =========
  symbol    main = pinC.3         'main power supply connected to pin C.3 (digital input)
  symbol  ADCval = w0             'used to store the ADC reading
  symbol   Vbatt = w1             'used to compute the battery voltage
  
  'The following five variables are used in the bintoascii statement.
  '(Variables b0 through b3 are already defined in the above two word variables.)
  symbol tenthou = b4
  symbol    thou = b5
  symbol    hund = b6
  symbol     ten = b7
  symbol    unit = b8
	
' === Begin Main Program ==================================================================
  adcconfig %011                                   'Vref+ is FVR, Vref- is 0V
  fvrsetup FVR2048                                 'set FVR at 2048mV
  
do
  readadc10 batt, ADCval                           'get ADCval    
  ADCval = 2 * ADCval                              'convert to mV

  bintoascii ADCval,tenthou,thou,hund,ten,unit     'convert to ASCII 
  sertxd ("Vadc = ",thou,".",hund,ten,unit,"V; ")  'display ADC voltage with decimal point
  
  Vbatt =  11 * ADCval                             'compute batt voltage (100k & 10k res)
  if tenthou = 0 then                              'blank any leading zero
    tenthou = " "
  endif
   
  bintoascii Vbatt,tenthou,thou,hund,ten,unit      'convert to ASCII
  sertxd ("Vbatt = ",tenthou,thou,".")             'display batt voltage with decimal point
  sertxd (hund,ten,unit,"V; ")

  sertxd ("Main Power ")                           'display main power status
  
  if main = 1 then
    sertxd ("good.",CR,LF)
  else
    sertxd ("failure!",CR,LF)
  endif

  wait 5                                           'slow down to about a five second loop
loop